@@ -20,6 +20,7 @@ sub timer {
    bless \(my $x = Event->timer (
       %arg,
       cb => sub {
+         # watcher gets canceled automatically
          $$rcb->();
       },
    )), $class
@@ -51,7 +52,5 @@ sub AnyEvent::Impl::Event::CondVar::wait {
    Event::one_event() while !${$_[0]};
 }
 
-$AnyEvent::MODEL = __PACKAGE__;
-
 1
 
